"""
========================================
Tools config
========================================
"""

config = {
    'ecs': [
        'DescribeInstances',
        'DescribeRegions',
        'DescribeZones',
        'DescribeAccountAttributes',
        'DescribeAvailableResource',
        'DescribeImages',
        'DescribeSecurityGroups',
        'DeleteInstances'
    ],
    'Vpc': [
        'DescribeVpcs',
        'DescribeVSwitches'
    ],
    'rds': [
        'DescribeDBInstances'
    ]
}














